/*
 * escape_ansi.h
 * -------------
 * Functions for escaping non-printable characters.
 *
 *
 * Copyright 2008, 2009 Sebastien Aperghis-Tramoni
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the same terms as Perl itself.
 */

/* public functions */
char *  escape_non_printable_chars(const char *);

